==> ctxR_1.0.0.tar.gz: ctxR/tests/testthat/chemical/chemical/property/search/by-dtxsid.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/property/search/by-dtxsid/", 
    status_code = 405L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Tue, 21 May 2024 17:13:53 GMT", allow = "POST", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "3be861d2-3246-48e9-4261-1c640f0e8e5f", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 d7b509440ac55e6d7b3c4c7ad48b08f2.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "IAH50-C2", `x-amz-cf-id` = "Q51rU61Aiu-Zwb1IR1Fb_hJXelpEqgDllJdQJleSvqGbAUCyJUSVrQ=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 405L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Tue, 21 May 2024 17:13:53 GMT", allow = "POST", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "3be861d2-3246-48e9-4261-1c640f0e8e5f", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 d7b509440ac55e6d7b3c4c7ad48b08f2.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "IAH50-C2", `x-amz-cf-id` = "Q51rU61Aiu-Zwb1IR1Fb_hJXelpEqgDllJdQJleSvqGbAUCyJUSVrQ=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x4d, 0x65, 0x74, 0x68, 0x6f, 0x64, 
    0x20, 0x4e, 0x6f, 0x74, 0x20, 0x41, 0x6c, 0x6c, 0x6f, 0x77, 
    0x65, 0x64, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x73, 0x74, 
    0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 0x20, 0x34, 0x30, 
    0x35, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 0x65, 0x74, 0x61, 
    0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x4d, 0x65, 0x74, 
    0x68, 0x6f, 0x64, 0x20, 0x27, 0x47, 0x45, 0x54, 0x27, 0x20, 
    0x69, 0x73, 0x20, 0x6e, 0x6f, 0x74, 0x20, 0x73, 0x75, 0x70, 
    0x70, 0x6f, 0x72, 0x74, 0x65, 0x64, 0x2e, 0x22, 0x2c, 0x0a, 
    0x20, 0x20, 0x22, 0x69, 0x6e, 0x73, 0x74, 0x61, 0x6e, 0x63, 
    0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x2f, 0x63, 0x68, 0x65, 
    0x6d, 0x69, 0x63, 0x61, 0x6c, 0x2f, 0x70, 0x72, 0x6f, 0x70, 
    0x65, 0x72, 0x74, 0x79, 0x2f, 0x73, 0x65, 0x61, 0x72, 0x63, 
    0x68, 0x2f, 0x62, 0x79, 0x2d, 0x64, 0x74, 0x78, 0x73, 0x69, 
    0x64, 0x2f, 0x22, 0x0a, 0x7d)), date = structure(1716311633, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 4e-05, 
    connect = 0, pretransfer = 0.000182, starttransfer = 0.250202, 
    total = 0.250239)), class = "response")

==> ctxR_1.1.1.tar.gz: ctxR/tests/testthat/chemical/chemical/property/search/by-dtxsid.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/property/search/by-dtxsid/", 
    status_code = 405L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Fri, 08 Nov 2024 15:46:57 GMT", allow = "POST", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "77538112-87d6-497d-42d7-4a1b82db1d87", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 58f689028f521999dd25fa234ad8a3f4.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "7oeTa5UOmXT8wzg02wlsjMn_9X7qQD_LS0pZOFoeoNRs1zPDA6MReg=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 405L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Fri, 08 Nov 2024 15:46:57 GMT", allow = "POST", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "77538112-87d6-497d-42d7-4a1b82db1d87", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 58f689028f521999dd25fa234ad8a3f4.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "7oeTa5UOmXT8wzg02wlsjMn_9X7qQD_LS0pZOFoeoNRs1zPDA6MReg=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x4d, 0x65, 0x74, 0x68, 0x6f, 0x64, 
    0x20, 0x4e, 0x6f, 0x74, 0x20, 0x41, 0x6c, 0x6c, 0x6f, 0x77, 
    0x65, 0x64, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x73, 0x74, 
    0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 0x20, 0x34, 0x30, 
    0x35, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 0x65, 0x74, 0x61, 
    0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x4d, 0x65, 0x74, 
    0x68, 0x6f, 0x64, 0x20, 0x27, 0x47, 0x45, 0x54, 0x27, 0x20, 
    0x69, 0x73, 0x20, 0x6e, 0x6f, 0x74, 0x20, 0x73, 0x75, 0x70, 
    0x70, 0x6f, 0x72, 0x74, 0x65, 0x64, 0x2e, 0x22, 0x2c, 0x0a, 
    0x20, 0x20, 0x22, 0x69, 0x6e, 0x73, 0x74, 0x61, 0x6e, 0x63, 
    0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x2f, 0x63, 0x68, 0x65, 
    0x6d, 0x69, 0x63, 0x61, 0x6c, 0x2f, 0x70, 0x72, 0x6f, 0x70, 
    0x65, 0x72, 0x74, 0x79, 0x2f, 0x73, 0x65, 0x61, 0x72, 0x63, 
    0x68, 0x2f, 0x62, 0x79, 0x2d, 0x64, 0x74, 0x78, 0x73, 0x69, 
    0x64, 0x2f, 0x22, 0x0a, 0x7d)), date = structure(1731080817, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 5.4e-05, 
    connect = 0, pretransfer = 0.000183, starttransfer = 0.23512, 
    total = 0.235176)), class = "response")
